@@ -11,6 +11,7 @@ package Kernel::Output::HTML::Preferences::Avatar;
 
 use strict;
 use warnings;
+use utf8;
 
 use Digest::MD5 qw(md5_hex);
 
@@ -30,6 +31,9 @@ sub new {
         die "Got no $Needed!" if ( !$Self->{$Needed} );
     }
 
+    my $AvatarEngine = $Kernel::OM->Get('Kernel::Config')->Get('Frontend::AvatarEngine');
+    return if $AvatarEngine eq 'None';
+
     return $Self;
 }
 
