@@ -513,19 +513,7 @@ sub _Show {
             sort keys %Actions;
     }
 
-    my $ACL = $TicketObject->TicketAcl(
-        Data          => \%PossibleActions,
-        Action        => $Self->{Action},
-        TicketID      => $Article{TicketID},
-        ReturnType    => 'Action',
-        ReturnSubType => '-',
-        UserID        => $Self->{UserID},
-    );
-
     my %AclAction = %PossibleActions;
-    if ($ACL) {
-        %AclAction = $TicketObject->TicketAclActionData();
-    }
 
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
@@ -534,6 +522,22 @@ sub _Show {
     my @ActionItems;
     if ( ref $ConfigObject->Get('Ticket::Frontend::PreMenuModule') eq 'HASH' ) {
         my %Menus = %{ $ConfigObject->Get('Ticket::Frontend::PreMenuModule') };
+
+        if (%Menus) {
+            my $ACL = $TicketObject->TicketAcl(
+                Data          => \%PossibleActions,
+                Action        => $Self->{Action},
+                TicketID      => $Article{TicketID},
+                ReturnType    => 'Action',
+                ReturnSubType => '-',
+                UserID        => $Self->{UserID},
+            );
+
+            if ($ACL) {
+                %AclAction = $TicketObject->TicketAclActionData();
+            }
+        }
+
         MENU:
         for my $Menu ( sort keys %Menus ) {
 
@@ -758,77 +762,6 @@ sub _Show {
         }
     }
 
-    # create output
-    $LayoutObject->Block(
-        Name => 'AgentAnswer',
-        Data => {
-            %Param,
-            %Article,
-            %AclAction,
-        },
-    );
-    if (
-        $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose}
-        && ( !defined $AclAction{AgentTicketCompose} || $AclAction{AgentTicketCompose} )
-        )
-    {
-        my $Access = 1;
-        my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketCompose');
-        if ( $Config->{Permission} ) {
-            my $Ok = $TicketObject->Permission(
-                Type     => $Config->{Permission},
-                TicketID => $Param{TicketID},
-                UserID   => $Self->{UserID},
-                LogNo    => 1,
-            );
-            if ( !$Ok ) {
-                $Access = 0;
-            }
-            if ($Access) {
-                $LayoutObject->Block(
-                    Name => 'AgentAnswerCompose',
-                    Data => {
-                        %Param,
-                        %Article,
-                        %AclAction,
-                    },
-                );
-            }
-        }
-    }
-    if (
-        $ConfigObject->Get('Frontend::Module')->{AgentTicketPhoneOutbound}
-        && (
-            !defined $AclAction{AgentTicketPhoneOutbound}
-            || $AclAction{AgentTicketPhoneOutbound}
-        )
-        )
-    {
-        my $Access = 1;
-        my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketPhoneOutbound');
-        if ( $Config->{Permission} ) {
-            my $OK = $TicketObject->Permission(
-                Type     => $Config->{Permission},
-                TicketID => $Param{TicketID},
-                UserID   => $Self->{UserID},
-                LogNo    => 1,
-            );
-            if ( !$OK ) {
-                $Access = 0;
-            }
-        }
-        if ($Access) {
-            $LayoutObject->Block(
-                Name => 'AgentAnswerPhoneOutbound',
-                Data => {
-                    %Param,
-                    %Article,
-                    %AclAction,
-                },
-            );
-        }
-    }
-
     # ticket type
     if ( $ConfigObject->Get('Ticket::Type') ) {
         $LayoutObject->Block(
@@ -1180,7 +1113,6 @@ sub _Show {
             Data => {
                 %Param,
                 %Article,
-                %AclAction,
             },
         );
     }
@@ -1248,14 +1180,7 @@ sub _Show {
         );
 
         # check if compose link should be shown
-        if (
-            $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose}
-            && (
-                !defined $AclAction{AgentTicketCompose}
-                || $AclAction{AgentTicketCompose}
-            )
-            )
-        {
+        if ( $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose} ) {
             my $Access = 1;
             my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketCompose');
             if ( $Config->{Permission} ) {
@@ -1308,7 +1233,6 @@ sub _Show {
         Data         => {
             %Param,
             %Article,
-            %AclAction,
         },
     );
     return \$Output;
