@@ -12,6 +12,7 @@ package Kernel::System::TemplateGenerator;
 
 use strict;
 use warnings;
+use utf8;
 
 use Kernel::Language;
 
@@ -145,6 +146,7 @@ sub Salutation {
         TicketData => \%Ticket,
         Data       => $Param{Data},
         UserID     => $Param{UserID},
+        Recipient  => $Param{Recipient},
     );
 
     # add urls
@@ -476,6 +478,7 @@ sub Template {
     );
 
     if ( $Self->{RichText} ) {
+        $TemplateText =~ s/&amp;nbsp;/&nbsp;/g;
         $TemplateText =~ s/&lt;/</g;
         $TemplateText =~ s/&gt;/>/g;
         $TemplateText =~ s/&quot;/"/g;
